@@ -28,6 +28,7 @@ class Window(Adw.ApplicationWindow):
 
     __gtype_name__ = "Window"
 
+    _create_view = None
     unlocked_db = None
 
     _create_database_bin = Gtk.Template.Child()
@@ -119,8 +120,6 @@ class Window(Adw.ApplicationWindow):
         # Display the screen with last opened files (or welcome page)
         if not gsecrets.config_manager.get_last_opened_list():
             logging.debug("No recent files saved")
-            self.view = self.View.WELCOME
-            return
 
         self.view = self.View.WELCOME
 
@@ -135,55 +134,37 @@ class Window(Adw.ApplicationWindow):
             self._open_database_in_window(path)
             return
 
-        opening_dialog = Gtk.FileChooserNative.new(
-            # NOTE: Filechooser title for opening an existing keepass safe kdbx file
-            _("Select Safe"),
-            self,
-            Gtk.FileChooserAction.OPEN,
-            None,
-            None,
-        )
-
         keepass_filter = Gtk.FileFilter()
         keepass_filter.add_mime_type("application/x-keepass2")
         keepass_filter.add_pattern("*.kdbx")
-        # NOTE: KeePass + version number is a proper name, do not translate
-        keepass_filter.set_name(_("KeePass 3.1/4 Database"))
-        opening_dialog.add_filter(keepass_filter)
+        # TRANSLATORS Safe as in strongbox.
+        keepass_filter.set_name("KeePass 3.1/4 " + _("Safe"))
 
         binary_filter = Gtk.FileFilter()
         binary_filter.add_mime_type("application/octet-stream")
         binary_filter.set_name(_("Any file type"))
-        opening_dialog.add_filter(binary_filter)
 
-        opening_dialog.connect(
-            "response",
-            self._on_open_filechooser_response,
-            opening_dialog,
-        )
-        opening_dialog.show()
+        filters = Gio.ListStore.new(Gtk.FileFilter)
+        filters.append(keepass_filter)
+        filters.append(binary_filter)
 
-    def _on_open_filechooser_response(
-        self,
-        dialog: Gtk.Dialog,
-        response: Gtk.ResponseType,
-        _dialog: Gtk.Dialog,
-    ) -> None:
-        dialog.destroy()
-        if response == Gtk.ResponseType.ACCEPT:
-            db_gfile = dialog.get_file()
-            if db_gfile is None:
-                logging.debug("No file selected")
-                return
+        dialog = Gtk.FileDialog.new()
+        dialog.props.title = _("Select Safe")
+        dialog.props.filters = filters
 
+        dialog.open(self, None, self._on_open_filechooser_response)
+
+    def _on_open_filechooser_response(self, dialog, result):
+        try:
+            db_gfile = dialog.open_finish(result)
+        except GLib.Error as err:
+            logging.debug("Could not open file: %s", err.message)
+        else:
             db_filename = db_gfile.get_path()
             logging.debug("File selected: %s", db_filename)
 
             self._open_database_in_window(db_filename)
 
-        elif response == Gtk.ResponseType.CANCEL:
-            logging.debug("File selection canceled")
-
     def _open_database_in_window(self, filepath):
         if self.unlocked_db:
             auto_save = gsecrets.config_manager.get_save_automatically()
@@ -228,6 +209,7 @@ class Window(Adw.ApplicationWindow):
         unlock_db = UnlockDatabase(self, database)
         self._unlock_database_bin.props.child = unlock_db
         self.view = self.View.UNLOCK_DATABASE
+        unlock_db.grab_entry_focus()
 
     #
     # Create Database Methods
@@ -235,38 +217,30 @@ class Window(Adw.ApplicationWindow):
 
     def on_new_database_action(self, _action: Gio.Action, _param: GLib.Variant) -> None:
         """Callback function to create a new safe."""
-        creation_dialog = Gtk.FileChooserNative.new(
-            # NOTE: Filechooser title for creating a new keepass safe kdbx file
-            _("Create Safe"),
-            self,
-            Gtk.FileChooserAction.SAVE,
-            _("_Create"),
-            None,
-        )
-        creation_dialog.set_current_name(_("Safe") + ".kdbx")
-        creation_dialog.set_modal(True)
-
         filter_text = Gtk.FileFilter()
-        # NOTE: KeePass + version number is a proper name, do not translate
-        filter_text.set_name(_("KeePass 3.1/4 Database"))
+        # TRANSLATORS Safe as in strongbox.
+        filter_text.set_name("KeePass 3.1/4 " + _("Safe"))
         filter_text.add_mime_type("application/x-keepass2")
-        creation_dialog.add_filter(filter_text)
 
-        creation_dialog.connect(
-            "response", self._on_create_filechooser_response, creation_dialog
-        )
-        creation_dialog.show()
+        filters = Gio.ListStore.new(Gtk.FileFilter)
+        filters.append(filter_text)
 
-    def _on_create_filechooser_response(
-        self, dialog: Gtk.Dialog, response: Gtk.ResponseType, _dialog: Gtk.Dialog
-    ) -> None:
-        dialog.destroy()
-        if response == Gtk.ResponseType.ACCEPT:
-            gfile = dialog.get_file()
-            if gfile is None:
-                logging.debug("No file selected")
-                return
+        dialog = Gtk.FileDialog.new()
+        # NOTE: Filechooser title for creating a new keepass safe kdbx file
+        dialog.props.title = _("Create Safe")
+        dialog.props.filters = filters
+        dialog.props.accept_label = _("_Create")
+        # NOTE: Safe as in strongbox
+        dialog.props.initial_name = _("Safe") + ".kdbx"
 
+        dialog.save(self, None, self._on_create_filechooser_response)
+
+    def _on_create_filechooser_response(self, dialog, result):
+        try:
+            gfile = dialog.save_finish(result)
+        except GLib.Error as err:
+            logging.debug("Could not save file: %s", err.message)
+        else:
             filepath = gfile.get_path()
             if self.unlocked_db:
                 auto_save = gsecrets.config_manager.get_save_automatically()
@@ -322,6 +296,7 @@ class Window(Adw.ApplicationWindow):
             else:
                 create_database = CreateDatabase(self, database_manager)
                 self._create_database_bin.props.child = create_database
+                self._create_view = create_database
                 self.view = self.View.CREATE_DATABASE
             finally:
                 self._spinner.stop()
@@ -444,6 +419,10 @@ class Window(Adw.ApplicationWindow):
         self.add_action(new_database_action)
         new_database_action.connect("activate", self.on_new_database_action)
 
+        go_back_action = Gio.SimpleAction.new("go_back", None)
+        self.add_action(go_back_action)
+        go_back_action.connect("activate", self.on_go_back_action)
+
         open_database_action = Gio.SimpleAction.new(
             "open_database", GLib.VariantType("s")
         )
@@ -458,7 +437,6 @@ class Window(Adw.ApplicationWindow):
             "db.add_group",
             "db.settings",
             "db.undo_delete",
-            "go_back",
             "element.delete",
             "entry.duplicate",
             "entry.references",
@@ -508,8 +486,6 @@ class Window(Adw.ApplicationWindow):
             action_db.undo_delete()
         elif name in ["db.save", "db.save_dirty"]:
             action_db.save_database()
-        elif name == "go_back":
-            action_db.go_back()
         elif name in ["db.add_entry", "db.add_group"]:
             if (
                 action_db.props.database_locked
@@ -536,6 +512,15 @@ class Window(Adw.ApplicationWindow):
     def on_settings_action(self, _action: Gio.Action, _param: GLib.Variant) -> None:
         SettingsDialog(self).present()
 
+    def on_go_back_action(self, _action: Gio.Action, _param: GLib.Variant) -> None:
+        if self.view == self.View.CREATE_DATABASE:
+            if create_view := self._create_view:
+                create_view.go_back()
+        else:
+            if action_db := self.unlocked_db:
+                if not action_db.props.database_locked:
+                    action_db.go_back()
+
     @Gtk.Template.Callback()
     def on_back_button_pressed(
         self,
